@@ -1,10 +1,11 @@
 /* Kernel includes */
+#include <linux/config.h>
 #include <linux/errno.h>
 #include <asm/segment.h>
 #include <linux/kernel.h>
 #include <linux/signal.h>
 #include <linux/module.h>
-#include "/linux/tools/version.h"
+#include <linux/version.h>
 
 char kernel_version[] = UTS_RELEASE;
 
